@@ -1,5 +1,5 @@
 Histogram <-
-function(x=NULL, data=d, filter=NULL,
+function(x=NULL, data=d, rows=NULL,
          stat_x=c("count", "proportion"),
          n_cat=getOption("n_cat"), Rmd=NULL,
 
@@ -182,8 +182,8 @@ function(x=NULL, data=d, filter=NULL,
       }
       data.vars <- as.list(seq_along(data))
       names(data.vars) <- names(data)
-      if (!missing(filter)) {  # subset rows
-        r <- eval(substitute(filter), envir=data, enclos=parent.frame())
+      if (!missing(rows)) {  # subset rows
+        r <- eval(substitute(rows), envir=data, enclos=parent.frame())
         r <- r & !is.na(r)  # set missing for a row to FALSE
         data <- data[r,,drop=FALSE]
       }
